@@ -3,6 +3,7 @@ import simplejson as json
 import re
 import decimal
 from datetime import datetime
+from pynamodb.models import MetaModel
 
 
 # class DecimalEncoder(json.JSONEncoder):
@@ -18,7 +19,10 @@ class ModelEncoder(json.JSONEncoder):
             return obj.attribute_values
         elif isinstance(obj, datetime):
             return obj.isoformat()
-        return json.JSONEncoder.default(self, obj)
+        elif isinstance(obj, MetaModel):
+            pass
+        else:
+            return json.JSONEncoder.default(self, obj)
 
 
 class APIFunction(LambdaFunction):
